program test_set_all_outerm

  ! Libraries:
  use jumble, only: pi

  use config_m, only: config, min_radius
  use derived_types, only: snapshot, shpc_slice_handler, null_ssh_contour, &
       missing_speed
  use input_ssh_m, only: input_ssh
  use set_all_outerm_m, only: set_all_outerm
  use shpc_close_m, only: shpc_close
  use shpc_create_m, only: shpc_create
  use write_snapshot_m, only: write_snapshot

  implicit none

  type(snapshot) s

  real corner(2)
  ! longitude and latitude of the corner of the whole grid, in rad

  real step(2) ! longitude and latitude steps, in rad
  integer nlon, nlat, i

  real, allocatable:: ssh(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if the grid is periodic
  ! in longitude, else (nlon, nlat). Sea-surface height, in m.

  real, allocatable:: u(:, :), v(:, :)
  ! (1 - max_radius(1):nlon + max_radius(1), nlat) if periodic, else
  ! (nlon, nlat) wind, in m s-1

  logical periodic ! grid is periodic in longitude
  TYPE(shpc_slice_handler) hshp_cyclo, hshp_anti

  !--------------------------------------------------------------

  call config
  call input_ssh(corner, step, nlon, nlat, periodic, ssh, u, v)
  call set_all_outerm(s, step, periodic, ssh, corner, &
       min_area = pi * (min_radius * 1e3)**2)

  do i = 1, s%number_extr
     s%list(i)%speed_cont = null_ssh_contour()
     s%list(i)%max_speed = missing_speed
     s%list(i)%radius4 = 0
  end do

  print *, "test_set_all_outerm: s%number_extr = ", s%number_extr
  print *, "test_set_all_outerm: Average number of points per outermost ", &
       "contour: ", sum(s%list%out_cont%n_points) / real(s%number_extr)
  call shpc_create(hshp_cyclo, shpc_dir = "SHPC", cyclone = .true., slice = 0)
  call shpc_create(hshp_anti, shpc_dir = "SHPC", cyclone = .false., slice = 0)
  call write_snapshot(s, hshp_cyclo, hshp_anti, date = 1)
  CALL shpc_close(hshp_cyclo)
  CALL shpc_close(hshp_anti)
  print *, 'test_set_all_outerm: Created shapefile collection in SHPC.'

end program test_set_all_outerm
