module config_graph_m

  implicit none

  integer, protected:: copy

  integer, protected:: max_delta = 1
  ! maximum interval of date indices between which we look for
  ! overlapping of eddies

  integer, protected:: dist_lim = 12
  ! We look for an overlapping eddy at dist_lim (in grid points) of
  ! the extremum of a given eddy.

  logical, protected:: cyclone = .true.

contains

  subroutine config_graph(rank)

    use, intrinsic:: ISO_FORTRAN_ENV

    ! Libraries:
#ifndef CPP_SEQUENTIAL
    use ezmpi, only: ezmpi_bcast
#endif
    use jumble, only: assert, pi

    use read_grid_m, only: periodic, step

    integer, intent(in):: rank

    ! Local:
    namelist /config_graph_nml/ max_delta, dist_lim, cyclone

    !-----------------------------------------------------------------

    if (rank == 0) then
       ! config_graph_nml:
       write(unit = error_unit, nml = config_graph_nml)
       write(unit = error_unit, fmt = *) "Enter namelist config_graph_nml."
       read(unit = *, nml = config_graph_nml)
       write(unit = *, nml = config_graph_nml)
       call assert(max_delta >= 1, "config_graph max_delta")
       if (periodic) call assert(2 * dist_lim * step(1) < PI, &
            "config_graph dist_lim")
       copy = merge(dist_lim, 0, periodic)
    end if

#ifndef CPP_SEQUENTIAL
    call ezmpi_bcast(max_delta, root = 0)
    call ezmpi_bcast(dist_lim, root = 0)
    call ezmpi_bcast(cyclone, root = 0)
    call ezmpi_bcast(copy, root = 0)
#endif

  end subroutine config_graph

end module config_graph_m
